CompletionOption

Struct CompletionOption 

pub struct CompletionOption {
    pub complete_var: String,
}
Configuration for the shell completion option.

Fields

complete_var: String

The environment variable that triggers completion.

Implementations

Source

impl CompletionOption

pub fn is_completion_requested(&self) -> bool

Check if completion is requested via environment variable.

pub fn get_completion_shell(&self) -> Option<String>

Get the completion shell type if completion is requested.

pub fn is_source_request(&self) -> bool

Check if this is a “source” request (print the completion script).

pub fn handle_completion(&self, cmd: &dyn CommandLike, prog_name: &str) -> bool

Handle completion if requested.

Returns true if completion was handled and the program should exit.