Module error

Module error 

Error types for click-rs.

This module provides a comprehensive error type hierarchy that mirrors Python Click’s exception system. All errors can be displayed to users with helpful context and hints.

Structs

ErrorContext
Context information for error formatting.

Enums

ClickError
The main error type for click-rs.
ParamType
The type of parameter that caused an error.

Type Aliases

Result
A specialized Result type for click-rs operations.