pub fn run(cmd: &dyn CommandLike)Expand description
Run a command/group with process arguments and standard Click-style error handling.
This helper prints formatted errors and exits with the command’s exit code.
pub fn run(cmd: &dyn CommandLike)Run a command/group with process arguments and standard Click-style error handling.
This helper prints formatted errors and exits with the command’s exit code.