ResultCallback

Type Alias ResultCallback 

pub type ResultCallback = Box<dyn Fn(&Context, Vec<Box<dyn Any + Send + Sync>>) -> Result<(), ClickError> + Send + Sync>;
Type for result callbacks that process subcommand return values.

The callback receives the context and a vector of return values from subcommand invocations. In chain mode, this will contain values from all chained commands; otherwise, it will contain a single value.

Aliased Type

pub struct ResultCallback(/* private fields */);