pub struct DateTimeType {
pub formats: Vec<String>,
}Expand description
A datetime parameter type that parses ISO 8601 format strings.
By default, attempts to parse using these formats (in order):
%Y-%m-%d(date only)%Y-%m-%dT%H:%M:%S(datetime with T separator)%Y-%m-%d %H:%M:%S(datetime with space separator)
Custom formats can be specified using the formats field.
Fields
formats: Vec<String>The datetime formats to try, in order.
Implementations
Sourceimpl DateTimeType
impl DateTimeType
Sourcepub const DEFAULT_FORMATS: &'static [&'static str]
pub const DEFAULT_FORMATS: &'static [&'static str]
Default datetime formats.
Sourcepub fn with_formats(
formats: impl IntoIterator<Item = impl Into<String>>,
) -> Self
pub fn with_formats( formats: impl IntoIterator<Item = impl Into<String>>, ) -> Self
Create a datetime type with custom formats.