PathType

Struct PathType 

pub struct PathType {
    pub exists: bool,
    pub file_okay: bool,
    pub dir_okay: bool,
    pub readable: bool,
    pub writable: bool,
    pub executable: bool,
    pub resolve_path: bool,
    pub allow_dash: bool,
}
A parameter type for file system paths with optional validation.

Unlike the File type, this returns the path as a PathBuf rather than opening the file.

Fields

exists: bool

Whether the path must exist.

file_okay: bool

Whether files are allowed.

dir_okay: bool

Whether directories are allowed.

readable: bool

Whether the path must be readable.

writable: bool

Whether the path must be writable.

executable: bool

Whether the path must be executable.

resolve_path: bool

Whether to resolve the path to an absolute path.

allow_dash: bool

Whether to allow “-” to indicate stdin/stdout.

Implementations

Source

impl PathType

pub const fn new() -> Self

Create a new path type with default settings.

pub const fn exists(self, exists: bool) -> Self

Require the path to exist.

pub const fn file_okay(self, file_okay: bool) -> Self

Allow only files (not directories).

pub const fn dir_okay(self, dir_okay: bool) -> Self

Allow only directories (not files).

pub const fn readable(self, readable: bool) -> Self

Require the path to be readable.

pub const fn writable(self, writable: bool) -> Self

Require the path to be writable.

pub const fn executable(self, executable: bool) -> Self

Require the path to be executable.

pub const fn resolve_path(self, resolve_path: bool) -> Self

Resolve the path to an absolute path.

pub const fn allow_dash(self, allow_dash: bool) -> Self

Allow “-” to indicate stdin/stdout.