pub struct UnprocessedType;Expand description
A type that passes through values without any processing.
This is useful when you want to defer processing to a callback or when working with raw byte paths.