pub struct CompletionOption {
pub complete_var: String,
}Expand description
Configuration for the shell completion option.
Fields
complete_var: StringThe environment variable that triggers completion.
Implementations
Sourceimpl CompletionOption
impl CompletionOption
Sourcepub fn is_completion_requested(&self) -> bool
pub fn is_completion_requested(&self) -> bool
Check if completion is requested via environment variable.
Sourcepub fn get_completion_shell(&self) -> Option<String>
pub fn get_completion_shell(&self) -> Option<String>
Get the completion shell type if completion is requested.
Sourcepub fn is_source_request(&self) -> bool
pub fn is_source_request(&self) -> bool
Check if this is a “source” request (print the completion script).
Sourcepub fn handle_completion(&self, cmd: &dyn CommandLike, prog_name: &str) -> bool
pub fn handle_completion(&self, cmd: &dyn CommandLike, prog_name: &str) -> bool
Handle completion if requested.
Returns true if completion was handled and the program should exit.