pub fn edit_text(
text: Option<&str>,
editor: Option<&str>,
extension: &str,
require_save: bool,
) -> Result<Option<String>>Expand description
Open a text editor for the user to edit content.
Arguments
text- Initial text to populate the editor witheditor- Editor command to use, or None to use $EDITOR/$VISUAL/viextension- File extension for the temporary filerequire_save- If true, return None if user didn’t save
Returns
The edited text, or None if editing was cancelled.