pub struct PathType {
pub exists: bool,
pub file_okay: bool,
pub dir_okay: bool,
pub readable: bool,
pub writable: bool,
pub executable: bool,
pub resolve_path: bool,
pub allow_dash: bool,
}Expand description
A parameter type for file system paths with optional validation.
Unlike the File type, this returns the path as a PathBuf rather
than opening the file.
Fields
exists: boolWhether the path must exist.
file_okay: boolWhether files are allowed.
dir_okay: boolWhether directories are allowed.
readable: boolWhether the path must be readable.
writable: boolWhether the path must be writable.
executable: boolWhether the path must be executable.
resolve_path: boolWhether to resolve the path to an absolute path.
allow_dash: boolWhether to allow “-” to indicate stdin/stdout.
Implementations
Sourceimpl PathType
impl PathType
Sourcepub const fn executable(self, executable: bool) -> Self
pub const fn executable(self, executable: bool) -> Self
Require the path to be executable.
Sourcepub const fn resolve_path(self, resolve_path: bool) -> Self
pub const fn resolve_path(self, resolve_path: bool) -> Self
Resolve the path to an absolute path.
Sourcepub const fn allow_dash(self, allow_dash: bool) -> Self
pub const fn allow_dash(self, allow_dash: bool) -> Self
Allow “-” to indicate stdin/stdout.